##  Setting the Default Dashboard
When you sign in to SAP LeanIX, you land on the default dashboard. The workspace admin configures whether users can set their default dashboard or not. If this is not allowed, you automatically land on the default dashboard set by the admin or the predefined dashboard. For more information, see [Default Dashboard](https://help.sap.com/docs/leanix/ea/dashboards-settings?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759a5e37a441014acd0dfe4da61c1c5__default_dashboard) in the administrator guide.
If selecting default dashboards is allowed, you can set any dashboard, except the predefined ones, as your default. To do that, in the upper-right corner of the dashboard, click the three-dot icon > Set as Default.
![Setting a Dashboard as Default](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741e9327a441014b89197cfd9417561_LowRes.png)
Setting a Dashboard as Default
You can also set a dashboard as default from the dashboard details page. To do that, enable the My Default Dashboard toggle, then save the changes.
